@@ -15,10 +15,20 @@
 #ifndef FEATHER_COMMON_H
 #define FEATHER_COMMON_H
 
+#include "feather/compatibility.h"
+
 namespace feather {
 
 static constexpr const char* FEATHER_MAGIC_BYTES = "FEA1";
 
+static constexpr const int kFeatherDefaultAlignment = 8;
+static constexpr const int kFeatherVersion = 2;
+
+static inline int64_t PaddedLength(int64_t nbytes) {
+  static const int64_t alignment = kFeatherDefaultAlignment;
+  return ((nbytes + alignment - 1) / alignment) * alignment;
+}
+
 namespace util {
 
 static inline size_t ceil_byte(size_t size) {
@@ -32,7 +42,7 @@ static inline int64_t bytes_for_bits(int64_t size) {
 static constexpr uint8_t BITMASK[] = {1, 2, 4, 8, 16, 32, 64, 128};
 
 static inline bool get_bit(const uint8_t* bits, int i) {
-  return static_cast<bool>(bits[i / 8] & BITMASK[i % 8]);
+  return (bits[i / 8] & BITMASK[i % 8]) != 0;
 }
 
 static inline bool bit_not_set(const uint8_t* bits, int i) {
@@ -47,6 +57,12 @@ static inline void set_bit(uint8_t* bits, int i) {
   bits[i / 8] |= BITMASK[i % 8];
 }
 
+static inline void* fill_buffer(void* buffer, int value, size_t n) {
+  if (buffer && n)
+    ::memset(buffer, value, n);
+  return buffer;
+}
+
 } // namespace util
 
 } // namespace feather
